import bpy
from bpy.types import AddonPreferences
from bpy.props import (
    BoolProperty,
    IntProperty,
    EnumProperty,
    FloatProperty,
    FloatVectorProperty,
    StringProperty,
)
from .keymaps import get_hotkey_entry_item
def filter_keymap_items(kmi):
    return (
            kmi.idname == "mlr.modal_lattice_res"
    )
class MLR_OT_restore(bpy.types.Operator):
    '''Restore Key Map Item'''
    bl_label = "Restore key map item"
    bl_idname = "mlr.restore_keymap"
    def execute(self, context):
        wm = context.window_manager
        kc = wm.keyconfigs.user

        if kc:
            for km in kc.keymaps:
                for kmi in filter(filter_keymap_items, km.keymap_items):
                    km.restore_item_to_default(kmi)

        return {'FINISHED'}

class MLR_Preferences(AddonPreferences):
    bl_idname = __package__

    tab_mlr: EnumProperty(
        name="Preferences Tab",
        items=[('UI', 'UI', ''),
               ('KEYMAPS', 'Keymaps', ''),
               ],
        default='UI',
    )

    Display_Shortcuts_Modal_Lattice: BoolProperty(

        default=True,
    )

    Color_Modal_Lattice: FloatVectorProperty(
        default=(0, .8, 1, 1),
        min=0,
        max=1,
        size=4,
        subtype='COLOR_GAMMA'
    )

    x_modal_text: IntProperty(

        default=125,
    )

    y_modal_text: IntProperty(
        default=310,
    )

    size_modal_text: IntProperty(
        default=25,
    )

    def draw(self, context):

        layout = self.layout
        row = layout.row(align=True)
        row.prop(self, "tab_mlr", expand=True)

        if self.tab_mlr == "UI":

            box = layout.box()
            row = box.row(align=True)
            row.label(text='Interface Settings:', )
            row = box.row(align=True)
            row.prop(self, "Display_Shortcuts_Modal_Lattice", text='Display  Modal Lattice Resolution ')
            row = box.row(align=True)
            row.prop(self, "Color_Modal_Lattice", text='Color for Modal lattice')
            row.prop(self, "size_modal_text", text='Text Size')
            row = box.row(align=True)
            row.label(text="Text Position")
            row.prop(self, "x_modal_text", text='X:')
            row.prop(self, "y_modal_text", text='Y:')

        if self.tab_mlr == "KEYMAPS":

            box = layout.box()
            box.label(text="Modal Lattice Resolution Hotkeys:")
            wm = bpy.context.window_manager
            kc = wm.keyconfigs.user
            km = kc.keymaps['3D View']

            for kmi in km.keymap_items:
                if kmi.idname == "mlr.modal_lattice_res":
                    split = box.split()
                    row = split.row(align=True)
                    row.prop(kmi, "show_expanded", text="", emboss=False)
                    row.prop(kmi, "active", text="", emboss=False)
                    row.label(text=kmi.name)

                    row = split.row()
                    row.prop(kmi, "map_type", text="")
                    row.prop(kmi, "type", text="", full_event=True)

                    if (not kmi.is_user_defined) and kmi.is_user_modified:
                        row.operator("mlr.restore_keymap", text="", icon="BACK")
                    else:
                        box = row.box()
                        box.scale_x = 0.75
                        box.scale_y = 0.55
                        box.label(text="", icon="BLANK1")



def get_preferences():
    return bpy.context.preferences.addons[__package__].preferences


register, unregister = bpy.utils.register_classes_factory((MLR_OT_restore, MLR_Preferences,))